;; Generated package description from url-http-oauth.el  -*- no-byte-compile: t -*-
(define-package "url-http-oauth" "0.8.4.0.20250626.204641" "OAuth 2.0 for URL library" '((emacs "24.4")) :commit "f951bb71c5c34542cc75940d5e179d023f352ad4" :url "https://elpa.gnu.org/packages/url-http-oauth.html" :authors '(("Thomas Fitzsimmons" . "fitzsim@fitzsim.org")) :maintainer '("Thomas Fitzsimmons" . "fitzsim@fitzsim.org") :keywords '("comm" "data" "processes" "hypermedia"))
